import * as React from 'react';
import { CustomClasses } from './Token';
export interface IlluminateProps {
    /**
     * The text to be highlighted
     */
    children: string;
    /**
     * The language definition, to be used to highlight the text.
     * This must match with one of the language names, used with `addLanguage`
     */
    lang: string;
    /**
     * Flag to toggle the addition of line-numbers to output.
     * **Note**: You might need to add appropriate styles for this to work.
     * See Illuminate Plugins for more details
     *
     * @default false
     */
    lineNumbers?: boolean;
    /**
     * Flag to toggle the addition of language name to output.
     * **Note**: You might need to add appropriate styles for this to work.
     * See Illuminate Plugins for more details
     *
     * @default false
     */
    showLanguage?: boolean;
    /**
     * By default, Illuminate uses fixed and generic class names.
     * Using this setting, you can cutomize those classes.
     * For example:
     *
     *   * You can namespace classes like `.illuminate--string` to avoid conflicts with existing CSS.
     *   * You can use [CSS Modules](https://github.com/css-modules/css-modules), like `.operator_93jsa`.
     *
     * @example
     *
     * {
     *      prefix: 'prefix-',
     *      map: {
     *          property: 'special-property',
     *          string: 'string_ch29s',
     *          operator: 'operator_93jsa'
     *      }
     * }
     */
    customClasses?: CustomClasses;
}
export declare class Illuminate extends React.PureComponent<IlluminateProps> {
    renderLineNumbers(code: string): JSX.Element;
    render(): string | JSX.Element;
}
