import * as React from 'react';
import * as cx from 'classnames';
import { tokenize, getLanguage } from 'illuminate-js';
import { TokenElement } from './Token';
export class Illuminate extends React.PureComponent {
    renderLineNumbers(code) {
        const match = code.match(/\n(?!$)/g);
        const linesNum = match ? match.length + 1 : 1;
        let lines = [];
        for (let i = 0; i < linesNum; i++) {
            lines.push(React.createElement("span", { key: `line-${i}`, className: "line-number" }));
        }
        return React.createElement("span", { className: "line-numbers-rows" }, lines);
    }
    render() {
        const { lang, children } = this.props;
        let token = children;
        const grammar = getLanguage(lang || '');
        if (!grammar) {
            return children;
        }
        token = tokenize(children, grammar);
        const className = cx(`language-${lang}`, {
            'line-numbers': this.props.lineNumbers,
            'show-language': this.props.showLanguage
        });
        return (React.createElement("pre", { className: className },
            React.createElement("code", null,
                this.props.showLanguage && React.createElement("span", { className: "show-language--lang" }, lang),
                React.createElement(TokenElement, { customClasses: this.props.customClasses, token: token }),
                this.props.lineNumbers && this.renderLineNumbers(children))));
    }
}
